rnalysis.filtering.Filter
=========================

.. currentmodule:: rnalysis.filtering

.. autoclass:: Filter


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::
    :toctree:

      ~Filter.__init__
      ~Filter.biotypes
      ~Filter.describe
      ~Filter.difference
      ~Filter.filter_biotype
      ~Filter.filter_by_ref_table_attr
      ~Filter.filter_percentile
      ~Filter.filter_top_n
      ~Filter.head
      ~Filter.intersection
      ~Filter.number_filters
      ~Filter.print_features
      ~Filter.save_csv
      ~Filter.split_by_percentile
      ~Filter.split_by_ref_table_attr
      ~Filter.symmetric_difference
      ~Filter.tail
      ~Filter.text_filters
      ~Filter.union





